@@ -9,6 +9,7 @@
 """Process list plugin."""
 
 import copy
+import functools
 import os
 
 from glances.globals import WINDOWS, key_exist_value_not_none_not_v, replace_special_chars
@@ -116,6 +117,22 @@ class PluginModel(GlancesPluginModel):
     stats is a list
     """
 
+    # Default list of processes stats to be grabbed / displayed
+    # Can be altered by glances_processes.disable_stats
+    enable_stats = [
+        'cpu_percent',
+        'memory_percent',
+        'memory_info',  # vms and rss
+        'pid',
+        'username',
+        'cpu_times',
+        'num_threads',
+        'nice',
+        'status',
+        'io_counters',  # ior and iow
+        'cmdline',
+    ]
+
     # Define the header layout of the processes list columns
     layout_header = {
         'cpu': '{:<6} ',
@@ -175,19 +192,8 @@ class PluginModel(GlancesPluginModel):
         # Use to optimize space (see https://github.com/nicolargo/glances/issues/959)
         self.pid_max = glances_processes.pid_max
 
-        # Set the default sort key if it is defined in the configuration file
-        if config is not None and 'processlist' in config.as_dict():
-            if 'sort_key' in config.as_dict()['processlist']:
-                logger.debug(
-                    'Configuration overwrites processes sort key by {}'.format(
-                        config.as_dict()['processlist']['sort_key']
-                    )
-                )
-                glances_processes.set_sort_key(config.as_dict()['processlist']['sort_key'], False)
-            if 'export' in config.as_dict()['processlist']:
-                glances_processes.export_process_filter = config.as_dict()['processlist']['export']
-                if args.export:
-                    logger.info("Export process filter is set to: {}".format(config.as_dict()['processlist']['export']))
+        # Load the config file
+        self.load(args, config)
 
         # The default sort key could also be overwrite by command line (see #1903)
         if args and args.sort_processes_key is not None:
@@ -195,6 +201,27 @@ class PluginModel(GlancesPluginModel):
 
         # Note: 'glances_processes' is already init in the processes.py script
 
+    def load(self, args, config):
+        # Set the default sort key if it is defined in the configuration file
+        if config is None or 'processlist' not in config.as_dict():
+            return
+        if 'sort_key' in config.as_dict()['processlist']:
+            logger.debug(
+                'Configuration overwrites processes sort key by {}'.format(config.as_dict()['processlist']['sort_key'])
+            )
+            glances_processes.set_sort_key(config.as_dict()['processlist']['sort_key'], False)
+        if 'export' in config.as_dict()['processlist']:
+            glances_processes.export_process_filter = config.as_dict()['processlist']['export']
+            if args.export:
+                logger.info("Export process filter is set to: {}".format(config.as_dict()['processlist']['export']))
+        if 'disable_stats' in config.as_dict()['processlist']:
+            logger.info(
+                'Followings processes stats wil not be displayed: {}'.format(
+                    config.as_dict()['processlist']['disable_stats']
+                )
+            )
+            glances_processes.disable_stats = config.as_dict()['processlist']['disable_stats'].split(',')
+
     def get_key(self):
         """Return the key of the list."""
         return 'pid'
@@ -203,7 +230,10 @@ class PluginModel(GlancesPluginModel):
         """Update processes stats using the input method."""
         # Update the stats
         if self.input_method == 'local':
-            stats = self.update_local()
+            # Update stats using the standard system lib
+            # Note: Update is done in the processcount plugin
+            # Just return the result
+            stats = glances_processes.get_list()
         else:
             stats = self.get_init_value()
 
@@ -216,17 +246,6 @@ class PluginModel(GlancesPluginModel):
 
         return self.stats
 
-    def update_local(self):
-        # Update stats using the standard system lib
-        # Note: Update is done in the processcount plugin
-        # Just return the result
-        if self.args.programs:
-            stats = glances_processes.get_list(as_programs=True)
-        else:
-            stats = glances_processes.get_list()
-
-        return stats
-
     def get_export(self):
         """Return the processes list to export.
         Not all the processeses are exported.
@@ -237,24 +256,16 @@ class PluginModel(GlancesPluginModel):
     def get_nice_alert(self, value):
         """Return the alert relative to the Nice configuration list"""
         value = str(value)
-        try:
-            if value in self.get_limit('nice_critical'):
-                return 'CRITICAL'
-        except KeyError:
-            pass
-        try:
-            if value in self.get_limit('nice_warning'):
-                return 'WARNING'
-        except KeyError:
-            pass
-        try:
-            if value in self.get_limit('nice_careful'):
-                return 'CAREFUL'
-        except KeyError:
-            pass
+        if self.get_limit('nice_critical') and value in self.get_limit('nice_critical'):
+            return 'CRITICAL'
+        if self.get_limit('nice_warning') and value in self.get_limit('nice_warning'):
+            return 'WARNING'
+        if self.get_limit('nice_careful') and value in self.get_limit('nice_careful'):
+            return 'CAREFUL'
+
         return 'DEFAULT'
 
-    def _get_process_curses_cpu(self, p, selected, args):
+    def _get_process_curses_cpu_percent(self, p, selected, args):
         """Return process CPU curses"""
         if key_exist_value_not_none_not_v('cpu_percent', p, ''):
             cpu_layout = self.layout_stat['cpu'] if p['cpu_percent'] < 100 else self.layout_stat['cpu_no_digit']
@@ -274,7 +285,7 @@ class PluginModel(GlancesPluginModel):
             ret = self.curse_add_line(msg)
         return ret
 
-    def _get_process_curses_mem(self, p, selected, args):
+    def _get_process_curses_memory_percent(self, p, selected, args):
         """Return process MEM curses"""
         if key_exist_value_not_none_not_v('memory_percent', p, ''):
             msg = self.layout_stat['mem'].format(p['memory_percent'])
@@ -310,58 +321,69 @@ class PluginModel(GlancesPluginModel):
             ret = self.curse_add_line(msg)
         return ret
 
+    def _get_process_curses_memory_info(self, p, selected, args):
+        return [
+            self._get_process_curses_vms(p, selected, args),
+            self._get_process_curses_rss(p, selected, args),
+        ]
+
+    def _get_process_curses_pid(self, p, selected, args):
+        """Return process PID curses"""
+        # Display processes, so the PID should be displayed
+        msg = self.layout_stat['pid'].format(p['pid'], width=self._max_pid_size())
+        return self.curse_add_line(msg)
+
     def _get_process_curses_username(self, p, selected, args):
         """Return process username curses"""
         if 'username' in p:
             # docker internal users are displayed as ints only, therefore str()
             # Correct issue #886 on Windows OS
             msg = self.layout_stat['user'].format(str(p['username'])[:9])
-            ret = self.curse_add_line(msg)
         else:
             msg = self.layout_header['user'].format('?')
-            ret = self.curse_add_line(msg)
-        return ret
+        return self.curse_add_line(msg)
 
-    def _get_process_curses_time(self, p, selected, args):
+    def _get_process_curses_cpu_times(self, p, selected, args):
         """Return process time curses"""
+        cpu_times = p['cpu_times']
         try:
             # Sum user and system time
-            user_system_time = p['cpu_times']['user'] + p['cpu_times']['system']
-        except (OverflowError, TypeError):
+            user_system_time = cpu_times['user'] + cpu_times['system']
+        except (OverflowError, TypeError, KeyError):
             # Catch OverflowError on some Amazon EC2 server
             # See https://github.com/nicolargo/glances/issues/87
             # Also catch TypeError on macOS
             # See: https://github.com/nicolargo/glances/issues/622
+            # Also catch KeyError (as no stats be present for processes of other users)
+            # See: https://github.com/nicolargo/glances/issues/2831
             # logger.debug("Cannot get TIME+ ({})".format(e))
             msg = self.layout_header['time'].format('?')
-            ret = self.curse_add_line(msg, optional=True)
-        else:
-            hours, minutes, seconds = seconds_to_hms(user_system_time)
-            if hours > 99:
-                msg = f'{hours:<7}h'
-            elif 0 < hours < 100:
-                msg = f'{hours}h{minutes}:{seconds}'
-            else:
-                msg = f'{minutes}:{seconds}'
-            msg = self.layout_stat['time'].format(msg)
-            if hours > 0:
-                ret = self.curse_add_line(msg, decoration='CPU_TIME', optional=True)
-            else:
-                ret = self.curse_add_line(msg, optional=True)
-        return ret
+            return self.curse_add_line(msg, optional=True)
 
-    def _get_process_curses_thread(self, p, selected, args):
+        hours, minutes, seconds = seconds_to_hms(user_system_time)
+        if hours > 99:
+            msg = f'{hours:<7}h'
+        elif 0 < hours < 100:
+            msg = f'{hours}h{minutes}:{seconds}'
+        else:
+            msg = f'{minutes}:{seconds}'
+
+        msg = self.layout_stat['time'].format(msg)
+        if hours > 0:
+            return self.curse_add_line(msg, decoration='CPU_TIME', optional=True)
+
+        return self.curse_add_line(msg, optional=True)
+
+    def _get_process_curses_num_threads(self, p, selected, args):
         """Return process thread curses"""
         if 'num_threads' in p:
             num_threads = p['num_threads']
             if num_threads is None:
                 num_threads = '?'
             msg = self.layout_stat['thread'].format(num_threads)
-            ret = self.curse_add_line(msg)
         else:
             msg = self.layout_header['thread'].format('?')
-            ret = self.curse_add_line(msg)
-        return ret
+        return self.curse_add_line(msg)
 
     def _get_process_curses_nice(self, p, selected, args):
         """Return process nice curses"""
@@ -390,7 +412,7 @@ class PluginModel(GlancesPluginModel):
             ret = self.curse_add_line(msg)
         return ret
 
-    def _get_process_curses_io(self, p, selected, args, rorw='ior'):
+    def _get_process_curses_io_read_write(self, p, selected, args, rorw='ior'):
         """Return process IO Read or Write curses"""
         if 'io_counters' in p and p['io_counters'][4] == 1 and p['time_since_update'] != 0:
             # Display rate if stats is available and io_tag ([4]) == 1
@@ -409,75 +431,18 @@ class PluginModel(GlancesPluginModel):
             ret = self.curse_add_line(msg, optional=True, additional=True)
         return ret
 
-    def _get_process_curses_io_read(self, p, selected, args):
-        """Return process IO Read curses"""
-        return self._get_process_curses_io(p, selected, args, rorw='ior')
+    def _get_process_curses_io_counters(self, p, selected, args):
+        return [
+            self._get_process_curses_io_read_write(p, selected, args, rorw='ior'),
+            self._get_process_curses_io_read_write(p, selected, args, rorw='iow'),
+        ]
 
-    def _get_process_curses_io_write(self, p, selected, args):
-        """Return process IO Write curses"""
-        return self._get_process_curses_io(p, selected, args, rorw='iow')
-
-    def get_process_curses_data(self, p, selected, args):
-        """Get curses data to display for a process.
-
-        - p is the process to display
-        - selected is a tag=True if p is the selected process
-        """
-        ret = [self.curse_new_line()]
-
-        # When a process is selected:
-        # * display a special character at the beginning of the line
-        # * underline the command name
-        ret.append(
-            self.curse_add_line(
-                unicode_message('PROCESS_SELECTOR') if (selected and not args.disable_cursor) else ' ', 'SELECTED'
-            )
-        )
-
-        # CPU
-        ret.append(self._get_process_curses_cpu(p, selected, args))
-
-        # MEM
-        ret.append(self._get_process_curses_mem(p, selected, args))
-        ret.append(self._get_process_curses_vms(p, selected, args))
-        ret.append(self._get_process_curses_rss(p, selected, args))
-
-        # PID
-        if not self.args.programs:
-            # Display processes, so the PID should be displayed
-            msg = self.layout_stat['pid'].format(p['pid'], width=self.__max_pid_size())
-        else:
-            # Display programs, so the PID should not be displayed
-            # Instead displays the number of children
-            msg = self.layout_stat['pid'].format(
-                len(p['childrens']) if 'childrens' in p else '_', width=self.__max_pid_size()
-            )
-        ret.append(self.curse_add_line(msg))
-
-        # USER
-        ret.append(self._get_process_curses_username(p, selected, args))
-
-        # TIME+
-        ret.append(self._get_process_curses_time(p, selected, args))
-
-        # THREAD
-        ret.append(self._get_process_curses_thread(p, selected, args))
-
-        # NICE
-        ret.append(self._get_process_curses_nice(p, selected, args))
-
-        # STATUS
-        ret.append(self._get_process_curses_status(p, selected, args))
-
-        # IO read/write
-        ret.append(self._get_process_curses_io_read(p, selected, args))
-        ret.append(self._get_process_curses_io_write(p, selected, args))
-
-        # Command line
+    def _get_process_curses_cmdline(self, p, selected, args):
+        """Return process cmdline curses"""
+        ret = []
         # If no command line for the process is available, fallback to the bare process name instead
         bare_process_name = p['name']
         cmdline = p.get('cmdline', '?')
-
         try:
             process_decoration = 'PROCESS_SELECTED' if (selected and not args.disable_cursor) else 'PROCESS'
             if cmdline:
@@ -501,6 +466,33 @@ class PluginModel(GlancesPluginModel):
             # Avoid crash after running fine for several hours #1335
             logger.debug(f"Can not decode command line '{cmdline}' ({e})")
             ret.append(self.curse_add_line('', splittable=True))
+        return ret
+
+    def get_process_curses_data(self, p, selected, args):
+        """Get curses data to display for a process.
+
+        - p is the process to display
+        - selected is a tag=True if p is the selected process
+        """
+        ret = [self.curse_new_line()]
+
+        # When a process is selected:
+        # * display a special character at the beginning of the line
+        # * underline the command name
+        ret.append(
+            self.curse_add_line(
+                unicode_message('PROCESS_SELECTOR') if (selected and not args.disable_cursor) else ' ', 'SELECTED'
+            )
+        )
+
+        for stat in [i for i in self.enable_stats if i not in glances_processes.disable_stats]:
+            msg = getattr(self, f'_get_process_curses_{stat}')(p, selected, args)
+            if isinstance(msg, list):
+                # ex: _get_process_curses_command return a list, so extend
+                ret.extend(msg)
+            else:
+                # ex: _get_process_curses_cpu return a dict, so append
+                ret.append(msg)
 
         return ret
 
@@ -523,24 +515,24 @@ class PluginModel(GlancesPluginModel):
 
         # Compute the sort key
         process_sort_key = glances_processes.sort_key
-        processes_list_sorted = self.__sort_stats(process_sort_key)
+        processes_list_sorted = self._sort_stats(process_sort_key)
 
         # Display extended stats for selected process
         #############################################
 
         if self.is_selected_process(args):
-            self.__msg_curse_extended_process(ret, glances_processes.extended_process)
+            self._msg_curse_extended_process(ret, glances_processes.extended_process)
 
         # Display others processes list
         ###############################
 
         # Header
-        self.__msg_curse_header(ret, process_sort_key, args)
+        self._msg_curse_header(ret, process_sort_key, args)
 
         # Process list
         # Loop over processes (sorted by the sort key previously compute)
         # This is a Glances bottleneck (see flame graph),
-        # TODO: get_process_curses_data should be optimzed
+        # TODO: get_process_curses_data should be optimized
         for position, process in enumerate(processes_list_sorted):
             ret.extend(self.get_process_curses_data(process, position == args.cursor_position, args))
 
@@ -548,15 +540,15 @@ class PluginModel(GlancesPluginModel):
         if glances_processes.process_filter is not None:
             if args.reset_minmax_tag:
                 args.reset_minmax_tag = not args.reset_minmax_tag
-                self.__mmm_reset()
-            self.__msg_curse_sum(ret, args=args)
-            self.__msg_curse_sum(ret, mmm='min', args=args)
-            self.__msg_curse_sum(ret, mmm='max', args=args)
+                self._mmm_reset()
+            self._msg_curse_sum(ret, args=args)
+            self._msg_curse_sum(ret, mmm='min', args=args)
+            self._msg_curse_sum(ret, mmm='max', args=args)
 
         # Return the message with decoration
         return ret
 
-    def __msg_curse_extended_process(self, ret, p):
+    def _msg_curse_extended_process(self, ret, p):
         """Get extended curses data for the selected process (see issue #2225)
 
         The result depends of the process type (process or thread).
@@ -583,158 +575,195 @@ class PluginModel(GlancesPluginModel):
          'cpu_max': 7.0,
          'cpu_mean': 3.2}
         """
-        if self.args.programs:
-            self.__msg_curse_extended_process_program(ret, p)
-        else:
-            self.__msg_curse_extended_process_thread(ret, p)
+        self._msg_curse_extended_process_thread(ret, p)
 
-    def __msg_curse_extended_process_program(self, ret, p):
-        # Title
-        msg = "Pinned program {} ('e' to unpin)".format(p['name'])
-        ret.append(self.curse_add_line(msg, "TITLE"))
-
-        ret.append(self.curse_new_line())
-        ret.append(self.curse_new_line())
-
-    def __msg_curse_extended_process_thread(self, ret, p):
-        # Title
+    def add_title_line(self, ret, prog):
         ret.append(self.curse_add_line("Pinned thread ", "TITLE"))
-        ret.append(self.curse_add_line(p['name'], "UNDERLINE"))
+        ret.append(self.curse_add_line(prog['name'], "UNDERLINE"))
         ret.append(self.curse_add_line(" ('e' to unpin)"))
 
-        # First line is CPU affinity
+        return ret
+
+    def add_cpu_line(self, ret, prog):
         ret.append(self.curse_new_line())
         ret.append(self.curse_add_line(' CPU Min/Max/Mean: '))
-        msg = '{: >7.1f}{: >7.1f}{: >7.1f}%'.format(p['cpu_min'], p['cpu_max'], p['cpu_mean'])
+        msg = '{: >7.1f}{: >7.1f}{: >7.1f}%'.format(prog['cpu_min'], prog['cpu_max'], prog['cpu_mean'])
         ret.append(self.curse_add_line(msg, decoration='INFO'))
-        if 'cpu_affinity' in p and p['cpu_affinity'] is not None:
+
+        return ret
+
+    def maybe_add_cpu_affinity_line(self, ret, prog):
+        if 'cpu_affinity' in prog and prog['cpu_affinity'] is not None:
             ret.append(self.curse_add_line(' Affinity: '))
-            ret.append(self.curse_add_line(str(len(p['cpu_affinity'])), decoration='INFO'))
+            ret.append(self.curse_add_line(str(len(prog['cpu_affinity'])), decoration='INFO'))
             ret.append(self.curse_add_line(' cores', decoration='INFO'))
-        if 'ionice' in p and p['ionice'] is not None and hasattr(p['ionice'], 'ioclass'):
+
+        return ret
+
+    def add_ionice_line(self, headers, default):
+        def add_ionice_using_matches(msg, v):
+            return msg + headers.get(v, default(v))
+
+        return add_ionice_using_matches
+
+    def get_headers(self, k):
+        # Linux: The scheduling class. 0 for none, 1 for real time, 2 for best-effort, 3 for idle.
+        default = {0: 'No specific I/O priority', 1: k + 'Real Time', 2: k + 'Best Effort', 3: k + 'IDLE'}
+
+        # Windows: On Windows only ioclass is used and it can be set to 2 (normal), 1 (low) or 0 (very low).
+        windows = {0: k + 'Very Low', 1: k + 'Low', 2: 'No specific I/O priority'}
+
+        return windows if WINDOWS else default
+
+    def maybe_add_ionice_line(self, ret, prog):
+        if 'ionice' in prog and prog['ionice'] is not None and hasattr(prog['ionice'], 'ioclass'):
             msg = ' IO nice: '
             k = 'Class is '
-            v = p['ionice'].ioclass
-            # Linux: The scheduling class. 0 for none, 1 for real time, 2 for best-effort, 3 for idle.
-            # Windows: On Windows only ioclass is used and it can be set to 2 (normal), 1 (low) or 0 (very low).
-            if WINDOWS:
-                if v == 0:
-                    msg += k + 'Very Low'
-                elif v == 1:
-                    msg += k + 'Low'
-                elif v == 2:
-                    msg += 'No specific I/O priority'
-                else:
-                    msg += k + str(v)
-            else:
-                if v == 0:
-                    msg += 'No specific I/O priority'
-                elif v == 1:
-                    msg += k + 'Real Time'
-                elif v == 2:
-                    msg += k + 'Best Effort'
-                elif v == 3:
-                    msg += k + 'IDLE'
-                else:
-                    msg += k + str(v)
+            v = prog['ionice'].ioclass
+
+            def default(v):
+                return k + str(v)
+
+            headers = self.get_headers(k)
+            msg = self.add_ionice_line(headers, default)(msg, v)
             #  value is a number which goes from 0 to 7.
             # The higher the value, the lower the I/O priority of the process.
-            if hasattr(p['ionice'], 'value') and p['ionice'].value != 0:
-                msg += ' (value {}/7)'.format(str(p['ionice'].value))
+            if hasattr(prog['ionice'], 'value') and prog['ionice'].value != 0:
+                msg += ' (value {}/7)'.format(str(prog['ionice'].value))
             ret.append(self.curse_add_line(msg, splittable=True))
 
-        # Second line is memory info
+        return ret
+
+    def maybe_add_memory_swap_line(self, ret, prog):
+        if 'memory_swap' in prog and prog['memory_swap'] is not None:
+            ret.append(
+                self.curse_add_line(
+                    self.auto_unit(prog['memory_swap'], low_precision=False), decoration='INFO', splittable=True
+                )
+            )
+            ret.append(self.curse_add_line(' swap ', splittable=True))
+
+        return ret
+
+    def add_memory_info_lines(self, ret, prog):
+        for key, val in prog['memory_info'].items():
+            ret.append(
+                self.curse_add_line(
+                    self.auto_unit(val, low_precision=False),
+                    decoration='INFO',
+                    splittable=True,
+                )
+            )
+            ret.append(self.curse_add_line(' ' + key + ' ', splittable=True))
+
+        return ret
+
+    def add_memory_line(self, ret, prog):
         ret.append(self.curse_new_line())
         ret.append(self.curse_add_line(' MEM Min/Max/Mean: '))
-        msg = '{: >7.1f}{: >7.1f}{: >7.1f}%'.format(p['memory_min'], p['memory_max'], p['memory_mean'])
+        msg = '{: >7.1f}{: >7.1f}{: >7.1f}%'.format(prog['memory_min'], prog['memory_max'], prog['memory_mean'])
         ret.append(self.curse_add_line(msg, decoration='INFO'))
-        if 'memory_info' in p and p['memory_info'] is not None:
+        if 'memory_info' in prog and prog['memory_info'] is not None:
             ret.append(self.curse_add_line(' Memory info: '))
-            for k, v in p['memory_info'].items():
-                ret.append(
-                    self.curse_add_line(
-                        self.auto_unit(v, low_precision=False),
-                        decoration='INFO',
-                        splittable=True,
-                    )
-                )
-                ret.append(self.curse_add_line(' ' + k + ' ', splittable=True))
-            if 'memory_swap' in p and p['memory_swap'] is not None:
-                ret.append(
-                    self.curse_add_line(
-                        self.auto_unit(p['memory_swap'], low_precision=False), decoration='INFO', splittable=True
-                    )
-                )
-                ret.append(self.curse_add_line(' swap ', splittable=True))
+            steps = [self.add_memory_info_lines, self.maybe_add_memory_swap_line]
+            ret = functools.reduce(lambda ret, step: step(ret, prog), steps, ret)
 
-        # Third line is for open files/network sessions
+        return ret
+
+    def add_io_and_network_lines(self, ret, prog):
         ret.append(self.curse_new_line())
         ret.append(self.curse_add_line(' Open: '))
         for stat_prefix in ['num_threads', 'num_fds', 'num_handles', 'tcp', 'udp']:
-            if stat_prefix in p and p[stat_prefix] is not None:
-                ret.append(self.curse_add_line(str(p[stat_prefix]), decoration='INFO'))
+            if stat_prefix in prog and prog[stat_prefix] is not None:
+                ret.append(self.curse_add_line(str(prog[stat_prefix]), decoration='INFO'))
                 ret.append(self.curse_add_line(' {} '.format(stat_prefix.replace('num_', ''))))
+        return ret
 
-        ret.append(self.curse_new_line())
-        ret.append(self.curse_new_line())
+    def _msg_curse_extended_process_thread(self, ret, prog):
+        # `append_newlines` has dummy arguments for piping thru `functools.reduce`
+        def append_newlines(ret, prog):
+            (ret.append(self.curse_new_line()),)
+            ret.append(self.curse_new_line())
 
-    def __msg_curse_header(self, ret, process_sort_key, args=None):
+            return ret
+
+        steps = [
+            self.add_title_line,
+            self.add_cpu_line,
+            self.maybe_add_cpu_affinity_line,
+            self.maybe_add_ionice_line,
+            self.add_memory_line,
+            self.add_io_and_network_lines,
+            append_newlines,
+        ]
+
+        functools.reduce(lambda ret, step: step(ret, prog), steps, ret)
+
+    def _msg_curse_header(self, ret, process_sort_key, args=None):
         """Build the header and add it to the ret dict."""
         sort_style = 'SORT'
 
-        if args.disable_irix and 0 < self.nb_log_core < 10:
-            msg = self.layout_header['cpu'].format('CPU%/' + str(self.nb_log_core))
-        elif args.disable_irix and self.nb_log_core != 0:
-            msg = self.layout_header['cpu'].format('CPU%/C')
-        else:
-            msg = self.layout_header['cpu'].format('CPU%')
-        ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'cpu_percent' else 'DEFAULT'))
-        msg = self.layout_header['mem'].format('MEM%')
-        ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'memory_percent' else 'DEFAULT'))
-        msg = self.layout_header['virt'].format('VIRT')
-        ret.append(self.curse_add_line(msg, optional=True))
-        msg = self.layout_header['res'].format('RES')
-        ret.append(self.curse_add_line(msg, optional=True))
-        if not self.args.programs:
-            msg = self.layout_header['pid'].format('PID', width=self.__max_pid_size())
-        else:
-            msg = self.layout_header['pid'].format('NPROCS', width=self.__max_pid_size())
-        ret.append(self.curse_add_line(msg))
-        msg = self.layout_header['user'].format('USER')
-        ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'username' else 'DEFAULT'))
-        msg = self.layout_header['time'].format('TIME+')
-        ret.append(
-            self.curse_add_line(msg, sort_style if process_sort_key == 'cpu_times' else 'DEFAULT', optional=True)
-        )
-        msg = self.layout_header['thread'].format('THR')
-        ret.append(self.curse_add_line(msg))
-        msg = self.layout_header['nice'].format('NI')
-        ret.append(self.curse_add_line(msg))
-        msg = self.layout_header['status'].format('S')
-        ret.append(self.curse_add_line(msg))
-        msg = self.layout_header['ior'].format('R/s')
-        ret.append(
-            self.curse_add_line(
-                msg, sort_style if process_sort_key == 'io_counters' else 'DEFAULT', optional=True, additional=True
-            )
-        )
-        msg = self.layout_header['iow'].format('W/s')
-        ret.append(
-            self.curse_add_line(
-                msg, sort_style if process_sort_key == 'io_counters' else 'DEFAULT', optional=True, additional=True
-            )
-        )
-        if args.is_standalone and not args.disable_cursor:
-            if self.args.programs:
-                shortkey = "('k' to kill)"
+        display_stats = [i for i in self.enable_stats if i not in glances_processes.disable_stats]
+
+        if 'cpu_percent' in display_stats:
+            if args.disable_irix and 0 < self.nb_log_core < 10:
+                msg = self.layout_header['cpu'].format('CPU%/' + str(self.nb_log_core))
+            elif args.disable_irix and self.nb_log_core != 0:
+                msg = self.layout_header['cpu'].format('CPU%/C')
             else:
-                shortkey = "('e' to pin | 'k' to kill)"
+                msg = self.layout_header['cpu'].format('CPU%')
+            ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'cpu_percent' else 'DEFAULT'))
+
+        if 'memory_percent' in display_stats:
+            msg = self.layout_header['mem'].format('MEM%')
+            ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'memory_percent' else 'DEFAULT'))
+        if 'memory_info' in display_stats:
+            msg = self.layout_header['virt'].format('VIRT')
+            ret.append(self.curse_add_line(msg, optional=True))
+            msg = self.layout_header['res'].format('RES')
+            ret.append(self.curse_add_line(msg, optional=True))
+        if 'pid' in display_stats:
+            msg = self.layout_header['pid'].format('PID', width=self._max_pid_size())
+            ret.append(self.curse_add_line(msg))
+        if 'username' in display_stats:
+            msg = self.layout_header['user'].format('USER')
+            ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'username' else 'DEFAULT'))
+        if 'cpu_times' in display_stats:
+            msg = self.layout_header['time'].format('TIME+')
+            ret.append(
+                self.curse_add_line(msg, sort_style if process_sort_key == 'cpu_times' else 'DEFAULT', optional=True)
+            )
+        if 'num_threads' in display_stats:
+            msg = self.layout_header['thread'].format('THR')
+            ret.append(self.curse_add_line(msg))
+        if 'nice' in display_stats:
+            msg = self.layout_header['nice'].format('NI')
+            ret.append(self.curse_add_line(msg))
+        if 'status' in display_stats:
+            msg = self.layout_header['status'].format('S')
+            ret.append(self.curse_add_line(msg))
+        if 'io_counters' in display_stats:
+            msg = self.layout_header['ior'].format('R/s')
+            ret.append(
+                self.curse_add_line(
+                    msg, sort_style if process_sort_key == 'io_counters' else 'DEFAULT', optional=True, additional=True
+                )
+            )
+            msg = self.layout_header['iow'].format('W/s')
+            ret.append(
+                self.curse_add_line(
+                    msg, sort_style if process_sort_key == 'io_counters' else 'DEFAULT', optional=True, additional=True
+                )
+            )
+        if args.is_standalone and not args.disable_cursor:
+            shortkey = "('e' to pin | 'k' to kill)"
         else:
             shortkey = ""
-        msg = self.layout_header['command'].format("Programs" if self.args.programs else "Command", shortkey)
-        ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'name' else 'DEFAULT'))
+        if 'cmdline' in display_stats:
+            msg = self.layout_header['command'].format("Command", shortkey)
+            ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'name' else 'DEFAULT'))
 
-    def __msg_curse_sum(self, ret, sep_char='_', mmm=None, args=None):
+    def _msg_curse_sum(self, ret, sep_char='_', mmm=None, args=None):
         """
         Build the sum message (only when filter is on) and add it to the ret dict.
 
@@ -748,11 +777,12 @@ class PluginModel(GlancesPluginModel):
             ret.append(self.curse_add_line(sep_char * 69))
             ret.append(self.curse_new_line())
         # CPU percent sum
-        msg = self.layout_stat['cpu'].format(self.__sum_stats('cpu_percent', mmm=mmm))
-        ret.append(self.curse_add_line(msg, decoration=self.__mmm_deco(mmm)))
+        msg = ' '
+        msg += self.layout_stat['cpu'].format(self._sum_stats('cpu_percent', mmm=mmm))
+        ret.append(self.curse_add_line(msg, decoration=self._mmm_deco(mmm)))
         # MEM percent sum
-        msg = self.layout_stat['mem'].format(self.__sum_stats('memory_percent', mmm=mmm))
-        ret.append(self.curse_add_line(msg, decoration=self.__mmm_deco(mmm)))
+        msg = self.layout_stat['mem'].format(self._sum_stats('memory_percent', mmm=mmm))
+        ret.append(self.curse_add_line(msg, decoration=self._mmm_deco(mmm)))
         # VIRT and RES memory sum
         if (
             'memory_info' in self.stats[0]
@@ -761,21 +791,21 @@ class PluginModel(GlancesPluginModel):
         ):
             # VMS
             msg = self.layout_stat['virt'].format(
-                self.auto_unit(self.__sum_stats('memory_info', sub_key='vms', mmm=mmm), low_precision=False)
+                self.auto_unit(self._sum_stats('memory_info', sub_key='vms', mmm=mmm), low_precision=False)
             )
-            ret.append(self.curse_add_line(msg, decoration=self.__mmm_deco(mmm), optional=True))
+            ret.append(self.curse_add_line(msg, decoration=self._mmm_deco(mmm), optional=True))
             # RSS
             msg = self.layout_stat['res'].format(
-                self.auto_unit(self.__sum_stats('memory_info', sub_key='rss', mmm=mmm), low_precision=False)
+                self.auto_unit(self._sum_stats('memory_info', sub_key='rss', mmm=mmm), low_precision=False)
             )
-            ret.append(self.curse_add_line(msg, decoration=self.__mmm_deco(mmm), optional=True))
+            ret.append(self.curse_add_line(msg, decoration=self._mmm_deco(mmm), optional=True))
         else:
             msg = self.layout_header['virt'].format('')
             ret.append(self.curse_add_line(msg))
             msg = self.layout_header['res'].format('')
             ret.append(self.curse_add_line(msg))
         # PID
-        msg = self.layout_header['pid'].format('', width=self.__max_pid_size())
+        msg = self.layout_header['pid'].format('', width=self._max_pid_size())
         ret.append(self.curse_add_line(msg))
         # USER
         msg = self.layout_header['user'].format('')
@@ -796,50 +826,50 @@ class PluginModel(GlancesPluginModel):
         if 'io_counters' in self.stats[0] and mmm is None:
             # IO read
             io_rs = int(
-                (self.__sum_stats('io_counters', 0) - self.__sum_stats('io_counters', sub_key=2, mmm=mmm))
+                (self._sum_stats('io_counters', 0) - self._sum_stats('io_counters', sub_key=2, mmm=mmm))
                 / self.stats[0]['time_since_update']
             )
             if io_rs == 0:
                 msg = self.layout_stat['ior'].format('0')
             else:
                 msg = self.layout_stat['ior'].format(self.auto_unit(io_rs, low_precision=True))
-            ret.append(self.curse_add_line(msg, decoration=self.__mmm_deco(mmm), optional=True, additional=True))
+            ret.append(self.curse_add_line(msg, decoration=self._mmm_deco(mmm), optional=True, additional=True))
             # IO write
             io_ws = int(
-                (self.__sum_stats('io_counters', 1) - self.__sum_stats('io_counters', sub_key=3, mmm=mmm))
+                (self._sum_stats('io_counters', 1) - self._sum_stats('io_counters', sub_key=3, mmm=mmm))
                 / self.stats[0]['time_since_update']
             )
             if io_ws == 0:
                 msg = self.layout_stat['iow'].format('0')
             else:
                 msg = self.layout_stat['iow'].format(self.auto_unit(io_ws, low_precision=True))
-            ret.append(self.curse_add_line(msg, decoration=self.__mmm_deco(mmm), optional=True, additional=True))
+            ret.append(self.curse_add_line(msg, decoration=self._mmm_deco(mmm), optional=True, additional=True))
         else:
             msg = self.layout_header['ior'].format('')
             ret.append(self.curse_add_line(msg, optional=True, additional=True))
             msg = self.layout_header['iow'].format('')
             ret.append(self.curse_add_line(msg, optional=True, additional=True))
         if mmm is None:
-            msg = ' < {}'.format('current')
+            msg = '< {}'.format('current')
             ret.append(self.curse_add_line(msg, optional=True))
         else:
-            msg = f' < {mmm}'
+            msg = f'< {mmm}'
             ret.append(self.curse_add_line(msg, optional=True))
-            msg = ' (\'M\' to reset)'
+            msg = '(\'M\' to reset)'
             ret.append(self.curse_add_line(msg, optional=True))
 
-    def __mmm_deco(self, mmm):
+    def _mmm_deco(self, mmm):
         """Return the decoration string for the current mmm status."""
         if mmm is not None:
             return 'DEFAULT'
         return 'FILTER'
 
-    def __mmm_reset(self):
+    def _mmm_reset(self):
         """Reset the MMM stats."""
         self.mmm_min = {}
         self.mmm_max = {}
 
-    def __sum_stats(self, key, sub_key=None, mmm=None):
+    def _sum_stats(self, key, sub_key=None, mmm=None):
         """Return the sum of the stats value for the given key.
 
         :param sub_key: If sub_key is set, get the p[key][sub_key]
@@ -860,7 +890,7 @@ class PluginModel(GlancesPluginModel):
                 ret += p[key][sub_key]
 
         # Manage Min/Max/Mean
-        mmm_key = self.__mmm_key(key, sub_key)
+        mmm_key = self._mmm_key(key, sub_key)
         if mmm == 'min':
             try:
                 if self.mmm_min[mmm_key] > ret:
@@ -884,17 +914,17 @@ class PluginModel(GlancesPluginModel):
 
         return ret
 
-    def __mmm_key(self, key, sub_key):
+    def _mmm_key(self, key, sub_key):
         ret = key
         if sub_key is not None:
             ret += str(sub_key)
         return ret
 
-    def __sort_stats(self, sorted_by=None):
+    def _sort_stats(self, sorted_by=None):
         """Return the stats (dict) sorted by (sorted_by)."""
         return sort_stats(self.stats, sorted_by, reverse=glances_processes.sort_reverse)
 
-    def __max_pid_size(self):
+    def _max_pid_size(self):
         """Return the maximum PID size in number of char."""
         if self.pid_max is not None:
             return len(str(self.pid_max))
