@@ -118,8 +118,8 @@ class PluginModel(GlancesPluginModel):
 
             # Get the CPU percent value (global and per core)
             # Stats is shared across all plugins
-            stats['cpu'] = cpu_percent.get()
-            stats['percpu'] = cpu_percent.get(percpu=True)
+            stats['cpu'] = cpu_percent.get_cpu()
+            stats['percpu'] = cpu_percent.get_percpu()
 
             # Get the virtual and swap memory
             stats['mem'] = psutil.virtual_memory().percent
@@ -159,7 +159,8 @@ class PluginModel(GlancesPluginModel):
                 self.views[key]['decoration'] = self.get_alert(self.stats[key], header=key)
 
         # Alert for LOAD
-        self.views['load']['decoration'] = self.get_alert(self.stats['load'], header='load')
+        if 'load' in self.stats:
+            self.views['load']['decoration'] = self.get_alert(self.stats['load'], header='load')
 
         # Define the list of stats to display
         self.views['list'] = self.stats_list
@@ -191,7 +192,12 @@ class PluginModel(GlancesPluginModel):
         ##########################
 
         # System information
-        if 'cpu_hz_current' in self.stats and 'cpu_hz' in self.stats:
+        if (
+            'cpu_hz_current' in self.stats
+            and self.stats['cpu_hz_current'] is not None
+            and 'cpu_hz' in self.stats
+            and self.stats['cpu_hz'] is not None
+        ):
             msg_freq = ' {:.2f}/{:.2f}GHz'.format(
                 self._hz_to_ghz(self.stats['cpu_hz_current']), self._hz_to_ghz(self.stats['cpu_hz'])
             )
