@@ -11,7 +11,7 @@
 import warnings
 from concurrent.futures import ThreadPoolExecutor
 from enum import Enum
-from typing import Any, Dict, List, Literal
+from typing import Any, Literal
 
 import psutil
 
@@ -105,7 +105,7 @@ class PluginModel(GlancesPluginModel):
         batpercent_plugin = BatPercentPluginModel(args=args, config=config)
         logger.debug(f"Battery sensor plugin init duration: {start_duration.get()} seconds")
 
-        self.sensors_grab_map: Dict[SensorType, Any] = {}
+        self.sensors_grab_map: dict[SensorType, Any] = {}
 
         if glances_grab_sensors_cpu_temp.init:
             self.sensors_grab_map[SensorType.CPU_TEMP] = glances_grab_sensors_cpu_temp
@@ -116,7 +116,7 @@ class PluginModel(GlancesPluginModel):
         self.sensors_grab_map[SensorType.HDD_TEMP] = hddtemp_plugin
         self.sensors_grab_map[SensorType.BATTERY] = batpercent_plugin
 
-        self.sensors_grab_map: Dict[SensorType, Any] = {}
+        self.sensors_grab_map: dict[SensorType, Any] = {}
 
         if glances_grab_sensors_cpu_temp.init:
             self.sensors_grab_map[SensorType.CPU_TEMP] = glances_grab_sensors_cpu_temp
@@ -138,7 +138,7 @@ class PluginModel(GlancesPluginModel):
         """Return the key of the list."""
         return 'label'
 
-    def __get_sensor_data(self, sensor_type: SensorType) -> List[Dict]:
+    def __get_sensor_data(self, sensor_type: SensorType) -> list[dict]:
         try:
             data = self.sensors_grab_map[sensor_type].update()
             data = self.__set_type(data, sensor_type)
@@ -203,7 +203,7 @@ class PluginModel(GlancesPluginModel):
             return self.has_alias("{}_{}".format(stats["label"], stats["type"]).lower())
         return stats["label"]
 
-    def __set_type(self, stats: List[Dict[str, Any]], sensor_type: SensorType) -> List[Dict[str, Any]]:
+    def __set_type(self, stats: list[dict[str, Any]], sensor_type: SensorType) -> list[dict[str, Any]]:
         """Set the plugin type.
 
         4 types of stats is possible in the sensors plugin:
@@ -214,12 +214,25 @@ class PluginModel(GlancesPluginModel):
         """
         for i in stats:
             # Set the sensors type
-            i.update({'type': str(sensor_type)})
+            i.update({'type': sensor_type})
             # also add the key name
             i.update({'key': self.get_key()})
 
         return stats
 
+    def __get_system_thresholds(self, sensor):
+        """Return the alert level thanks to the system thresholds"""
+        alert = 'OK'
+        if sensor['critical'] is None:
+            alert = 'DEFAULT'
+        elif sensor['value'] >= sensor['critical']:
+            alert = 'CRITICAL'
+        elif sensor['warning'] is None:
+            alert = 'DEFAULT'
+        elif sensor['value'] >= sensor['warning']:
+            alert = 'WARNING'
+        return alert
+
     def update_views(self):
         """Update stats views."""
         # Call the father's method
@@ -231,27 +244,22 @@ class PluginModel(GlancesPluginModel):
             if not i['value']:
                 continue
             # Alert processing
-            if i['type'] == SensorType.CPU_TEMP:
-                if self.is_limit('critical', stat_name=SensorType.CPU_TEMP + '_' + i['label']):
-                    # By default use the thresholds configured in the glances.conf file (see #2058)
-                    alert = self.get_alert(current=i['value'], header=SensorType.CPU_TEMP + '_' + i['label'])
+            stat_type = i['type'] if isinstance(i['type'], str) else i['type'].value
+            if stat_type == SensorType.CPU_TEMP:
+                if self.is_limit('critical', stat_name=stat_type + '_' + i['label']):
+                    # Get thresholds for the specific sensor in the glances.conf file (see #2058)
+                    alert = self.get_alert(current=i['value'], header=stat_type + '_' + i['label'])
+                elif self.is_limit('critical', stat_name=stat_type):
+                    # Get thresholds for the sensor type in the glances.conf file (see #3049)
+                    alert = self.get_alert(current=i['value'], header=stat_type)
                 else:
                     # Else use the system thresholds
-                    if i['critical'] is None:
-                        alert = 'DEFAULT'
-                    elif i['value'] >= i['critical']:
-                        alert = 'CRITICAL'
-                    elif i['warning'] is None:
-                        alert = 'DEFAULT'
-                    elif i['value'] >= i['warning']:
-                        alert = 'WARNING'
-                    else:
-                        alert = 'OK'
-            elif i['type'] == SensorType.BATTERY:
+                    alert = self.__get_system_thresholds(i)
+            if stat_type == SensorType.BATTERY:
                 # Battery is in %
-                alert = self.get_alert(current=100 - i['value'], header=i['type'])
+                alert = self.get_alert(current=100 - i['value'], header=stat_type)
             else:
-                alert = self.get_alert(current=i['value'], header=i['type'])
+                alert = self.get_alert(current=i['value'], header=stat_type)
             # Set the alert in the view
             self.views[i[self.get_key()]]['value']['decoration'] = alert
 
@@ -280,7 +288,7 @@ class PluginModel(GlancesPluginModel):
         if max_width:
             name_max_width = max_width - 12
         else:
-            # No max_width defined, return an emptu curse message
+            # No max_width defined, return an empty curse message
             logger.debug(f"No max_width defined for the {self.plugin_name} plugin, it will not be displayed.")
             return ret
 
@@ -340,7 +348,7 @@ class GlancesGrabSensors:
         except AttributeError:
             logger.debug(f"Cannot grab {sensor_type}. Platform not supported.")
 
-    def __fetch_psutil(self) -> Dict[str, list]:
+    def __fetch_psutil(self) -> dict[str, list]:
         if self.sensor_type == SensorType.CPU_TEMP:
             # Solve an issue #1203 concerning a RunTimeError warning message displayed
             # in the curses interface.
@@ -355,7 +363,7 @@ class GlancesGrabSensors:
 
         raise ValueError(f"Unsupported sensor_type: {self.sensor_type}")
 
-    def update(self) -> List[dict]:
+    def update(self) -> list[dict]:
         """Update the stats."""
         if not self.init:
             return []
